@@ -185,7 +185,7 @@ class Broker(Protocol):
         raise NotImplementedError
 
     @abstractmethod
-    def unlock(self) -> Self:
+    def unsafe_unlocking(self) -> None:
         raise NotImplementedError
 
     @abstractmethod
@@ -295,12 +295,10 @@ class Locator(Broker):
 
         return self
 
-    def unlock(self) -> Self:
+    def unsafe_unlocking(self) -> None:
         for injectable in self.__injectables:
             injectable.unlock()
 
-        return self
-
     async def all_ready(self) -> None:
         for injectable in self.__injectables:
             if injectable.is_locked:
@@ -811,17 +809,16 @@ class Module(Broker, EventListener):
         event = UnlockCalled()
 
         with self.dispatch(event, lock_bypass=True):
-            for broker in self.__brokers:
-                broker.unlock()
+            self.unsafe_unlocking()
 
         return self
 
+    def unsafe_unlocking(self) -> None:
+        for broker in self.__brokers:
+            broker.unsafe_unlocking()
+
     def load_profile(self, *names: str) -> ContextManager[Self]:
-        modules = tuple(self.from_name(name) for name in names)
-
-        for module in modules:
-            module.unlock()
-
+        modules = (self.from_name(name) for name in names)
         self.unlock().init_modules(*modules)
 
         @contextmanager
